@@ -4,6 +4,7 @@ use crate::encrypt::key::get_user_key;
 use crate::file::get_file_bytes;
 use crate::file::overwrite_check;
 use crate::file::write_encrypted_data_to_file;
+use crate::global::BLOCK_SIZE;
 use crate::hashing::hash_data_blake3;
 use anyhow::Context;
 use anyhow::{Ok, Result};
@@ -34,7 +35,7 @@ pub fn encrypt_file(
     println!("Read {} [took {:.2}s]", input, read_duration.as_secs_f32());
 
     println!(
-        "Encrypting {} in legacy mode (this may take a while)",
+        "Encrypting {} in memory mode (this may take a while)",
         input
     );
     let encrypt_start_time = Instant::now();
@@ -85,6 +86,13 @@ pub fn encrypt_file_stream(
     let raw_key = get_user_key(keyfile)?;
 
     let mut input_file = File::open(input).context("Unable to open file")?;
+    let file_size = input_file.metadata().unwrap().len();
+
+    if file_size <= BLOCK_SIZE.try_into().unwrap() {
+        println!("Input file size is less than the stream block size - redirecting to memory mode");
+        return encrypt_file(input, output, keyfile, hash_mode, skip, bench)
+    }
+
     let mut output_file = File::create(output).context("Unable to open output file")?;
 
     println!(
